pf_forms
open | /demo/pf_forms.html |
assertElementPresent | target |
assertText | target | Target
click | text |
waitForText | target | text
assertText | target | text
click | text-by-name |
waitForText | target | text-by-name
assertText | target | text-by-name
click | textarea |
waitForText | target | textarea
assertText | target | textarea
click | textarea-by-name |
waitForText | target | textarea-by-name
assertText | target | textarea-by-name
click | radio1 |
waitForText | target | radio-1
assertText | target | radio-1
click | radio-by-name |
waitForText | target | radio-2
assertText | target | radio-2
click | fullform-current |
waitForText | target | [('listval', ['listval1', 'listval2']), ('multiple-select', ['Value 1', 'Value 3']), ('recordsval', [{'a': 'recordval_a_1', 'b': 'recordval_b_1'}, {'a': 'recordval_a_2', 'b': 'recordval_b_2'}]), ('recordval', {'a': 'recordval_a', 'b': 'recordval_b'}), ('value1', 'value1'), ('value2', 'value2')]
verifyTextPresent | [('listval', ['listval1', 'listval2']), ('multiple-select', ['Value 1', 'Value 3']), ('recordsval', [{'a': 'recordval_a_1', 'b': 'recordval_b_1'}, {'a': 'recordval_a_2', 'b': 'recordval_b_2'}]), ('recordval', {'a': 'recordval_a', 'b': 'recordval_b'}), ('value1', 'value1'), ('value2', 'value2')] |
click | fullform-disabled |
waitForText | target | [('listval', ['listval1', 'listval2']), ('multiple-select', ['Value 1', 'Value 3']), ('recordsval', [{'a': 'recordval_a_1', 'b': 'recordval_b_1'}, {'a': 'recordval_a_2', 'b': 'recordval_b_2'}]), ('recordval', {'a': 'recordval_a', 'b': 'recordval_b'}), ('value2', 'value2')]
verifyTextPresent | [('listval', ['listval1', 'listval2']), ('multiple-select', ['Value 1', 'Value 3']), ('recordsval', [{'a': 'recordval_a_1', 'b': 'recordval_b_1'}, {'a': 'recordval_a_2', 'b': 'recordval_b_2'}]), ('recordval', {'a': 'recordval_a', 'b': 'recordval_b'}), ('value2', 'value2')] |